#
# spec file for package gops
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         google
%global repo            gops
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           gops
Version:        0.3.27
Release:        1.4
Summary:        A tool to list and diagnose Go processes currently running on your system
License:        BSD-3-Clause-Clear
Group:          System/Monitoring
URL:            https://%{provider_prefix}
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.17

%description
gops is a command to list and diagnose Go processes currently running on your
system. For processes that starts the diagnostics agent, gops can report
additional information such as the current stack trace, Go version, memory stats,
etc. It is possible to use gops tool both in local and remote mode.

%prep
%autosetup -a 1

%build
go build \
   -mod=vendor \
   -v -p 4 -x \
%ifnarch ppc64 ppc64le riscv64
   -buildmode=pie \
%endif
   %{import_path}

%install
go install \
   -mod=vendor \
   -v -p 4 -x \
%ifnarch ppc64 ppc64le riscv64
   -buildmode=pie \
%endif
   %{import_path}
install -D -m0755 %{name} %{buildroot}%{_bindir}/%{name}

%check
# execute the binary as a basic check
./%{name} --help

%files
%{_bindir}/%{name}

%changelog
* Tue Jul 25 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * Update to BuildRequires: golang(API) >= 1.17 to match go.mod
  * Add basic %%check to run packaged executable binary --help
* Tue Jul 25 2023 andrea.manzini@suse.com
- Update to version 0.3.27:
  * cmd/shared: add 'off' option to setgc (#201)
  * bump build deps
  * go.mod: bump to Go 1.17
  * Migrate gops to use spf13/cobra for command execution
  * vendor: include cobra
  * internal/cmd: Move code here from the main package
* Fri Jul  8 2022 jkowalczyk@suse.com
- Update to version 0.3.25:
  * Only report CPU percentage per period if period is > 0
  * ci: run tests with -race
  * agent: fix data race in Listen
* Mon Jun 27 2022 Jeff Kowalczyk <jkowalczyk@suse.com>
- Remove usage of obsolete macro golang-packaging macro %%goprovides
  and %%goprep
- Use BuildRequires: golang(API) >= 1.13 formerly golang-packaging.
  Alternatively could use BuildRequires: go
- Use tar_scm for changelog automation and tarball generation
- Use OBS Source Service obs-service-go_modules for vendoring.
  Upstream commits vendor dir but this is not best practice and
  contents can skew. Treat go.mod as the single source of truth.
* Mon Jun 27 2022 jkowalczyk@suse.com
- Update to version 0.3.24:
  * internal: inline getOSUserConfigDir
  * Sort tree output by PPID
  * internal: remove getOSUserConfigDir fallback for Go <= 1.13 (#170)
  * go.mod, vendor: update dependencies
  * Bump minimum Go version to 1.13 (#169)
* Mon Jun 27 2022 jkowalczyk@suse.com
- Update to version 0.3.23:
  * Remove CircleCI
  * goprocess: use debug/buildinfo on Go 1.18 and newer
  * Update CI to Go 1.18
  * Fix minor white space issue in README.md (#162)
  * Fix minor typo in README.md (#161)
  * Error out when the given duration is negative (#155)
* Mon Jun 27 2022 jkowalczyk@suse.com
- Update to version 0.3.22:
  * agent: rename setsockoptReuseAddrAndPort to setReuseAddrAndPortSockopts
  * agent: fix solaris build
* Mon Jun 27 2022 jkowalczyk@suse.com
- Update to version 0.3.21:
  * go.mod, vendor: update gopsutil and go-ole to fix windows/arm64 build
* Fri Oct  8 2021 Michał Rostecki <mrostecki@suse.com>
- Update to 0.3.20
  * README.md: update installation instructions (#148)
  * Update Go to 1.17, update dependencies (#150)
* Thu Jun 10 2021 Michał Rostecki <mrostecki@suse.com>
- Update to 0.3.18
  * Support for reporting the percent of CPU time usage within
    given time
  * agent: mention SO_REUSEPORT in Options.ReuseSocketAddrAndPort
    godoc
* Tue Jul 10 2018 mrostecki@suse.com
- Update to 0.3.4
  * vendor: dep ensure -update github.com/shirou/gopsutil (#79)
    gopsutil library is licensed under BSD, but the previous
    version contained some GPL-licensed code which is a violation
    of GPL license. The updated version doesn't contain
    GPL-licensed code anymore.
    https://github.com/shirou/gopsutil/issues/518
- Make use of golang-packaging macros
* Wed Mar 21 2018 mrostecki@suse.com
- Initial release
